@@ -21,7 +21,7 @@ BIN_DIR="$( cd -P "$( dirname "${BASH_SOURCE:-0}" )" && pwd )"
 hadoop fs -put $BIN_DIR/../data/kmeans /user/$USER/
 
 # Comments for all parameters:
-#  '../mapreduce-lib/guagua-mapreduce-examples-0.4.2.jar': Jar files include master, worker and user intercepters
+#  '../mapreduce-lib/guagua-mapreduce-examples-0.5.0.jar': Jar files include master, worker and user intercepters
 #  '-i kmeans': '-i' means guagua application input, should be HDFS input file or folder
 #  '-z ${ZOOKEEPER_SERVERS}': '-z' is used to configure zookeeper server, this should be placed by real zookeeper server
 #                            The format is like '<zkServer1:zkPort1,zkServer2:zkPort2>'
@@ -42,11 +42,10 @@ hadoop fs -put $BIN_DIR/../data/kmeans /user/$USER/
 #  '-Dkmeans.data.output=kmeans-tags': new data file folder with tag at last column
 #  '-Dguagua.master.intercepters=ml.shifu.guagua.mapreduce.example.kmeans.KMeansCentriodsOutput': User master interceptors
 
-./guagua jar ../mapreduce-lib/guagua-mapreduce-examples-0.4.2.jar \
+$BIN_DIR/guagua jar $BIN_DIR/../mapreduce-lib/guagua-mapreduce-examples-0.5.0.jar \
         -i kmeans  \
         -w ml.shifu.guagua.mapreduce.example.kmeans.KMeansWorker  \
         -m ml.shifu.guagua.mapreduce.example.kmeans.KMeansMaster  \
-        -c 10 \
         -n "Guagua-KMeans-Master-Workers-Job" \
         -mr ml.shifu.guagua.mapreduce.example.kmeans.KMeansMasterParams \
         -wr ml.shifu.guagua.mapreduce.example.kmeans.KMeansWorkerParams \
